@@ -24,6 +24,7 @@ import sys
 import getpass
 from types import StringType
 import string
+import glob
 import pwd
 import itertools
 
@@ -169,12 +170,13 @@ def getAvailableVideo(prefix="/"):
                     getDistfilesVideo(prefix=prefix)))
 
 
-def getPasswdUsers(minId=1000, maxId=65000, prefix="/"):
+def getPasswdUsers(minId=1000, maxId=65000, prefix="/",
+                   datafile="etc/passwd"):
     """
     Get users from passwd from minId to maxId
     """
     retList = []
-    fileName = path.join(prefix, "etc/passwd")
+    fileName = path.join(prefix, datafile)
     if os.access(fileName, os.R_OK):
         reNumb = re.compile("^\d+$")
         lenData = 7
@@ -221,6 +223,7 @@ class CmdlineParams(object):
     Domain = "domain"
     DomainPassword = "domain_pw"
     Audio = "audio"
+    Clock = "clock"
 
 
 def getValueFromCmdLine(option, num=None):
@@ -241,7 +244,8 @@ def getValueFromCmdLine(option, num=None):
         CmdlineParams.Composite,
         CmdlineParams.Domain,
         CmdlineParams.DomainPassword,
-        CmdlineParams.Audio)
+        CmdlineParams.Audio,
+        CmdlineParams.Clock)
     # try get timezone from kernel calculate param
     try:
         if num is None:
@@ -418,15 +422,15 @@ def getCompositeFromXorgconf(prefix="/"):
     return None
 
 
-def getKernelUid(device):
+def getKernelUid(dev):
     """Get Kernel UID by UUID of device"""
     blkidProcess = process('/sbin/blkid', '-c', '/dev/null', '-s', 'UUID',
-                           '-o', 'value', device)
+                           '-o', 'value', dev)
     res = blkidProcess.read().strip()
     if res:
         return res[:8]
     else:
-        return device.replace("/", "")
+        return dev.replace("/", "")
 
 
 def dict_by_columns(i, sep, key, value):
@@ -498,8 +502,8 @@ def mountEcryptfs(userName, userPwd, userDir):
     userPwd: пароль пользователя
     userDir: домашний каталог пользователя
     """
-    from calculate.lib.utils.files import (process, readLinesFile, STDOUT,
-                                           isMount)
+    from calculate.lib.utils.files import (process, readLinesFile, STDOUT)
+    from calculate.lib.utils.mount import isMount
 
     if ".Private" in isMount(userDir):
         return True
@@ -579,3 +583,9 @@ def getPortageUidGid():
         return data.pw_uid, data.pw_gid
     else:
         return 250, 250
+
+def getXorgConfContent(prefix="/"):
+    return "\n".join(open(x,'r').read() for x in 
+                     [path.join(prefix, "etc/X11/xorg.conf")] + 
+                     glob.glob(path.join(prefix,"etc/X11/xorg.conf.d/*"))
+                     if path.isfile(x))
