@@ -20,6 +20,12 @@ import re
 from calculate.lib.utils.tools import SingletonParam
 import files
 import device
+import xattr
+import errno
+from contextlib import contextmanager
+from files import process, makeDirectory
+from tools import traverse
+import tempfile
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
@@ -218,3 +224,102 @@ def childMounts(pathname):
                              map(lambda x: x.split(" "),
                                  open(mtabFile)))),
                   [])
+
+class MountError(Exception):
+    pass
+
+def mount(source, target, fstype=None, options=None):
+    params = [source, target]
+    if options is not None:
+        params.insert(0, "-o%s"%",".join(traverse([options])))
+    if fstype is not None:
+        params.insert(0, "-t%s"%fstype)
+    p = process("/bin/mount", *params)
+    if p.success():
+        return True
+    else:
+        raise MountError(
+            _("Failed to mount {source} to {target}").format(
+                source=source,
+                target=target) +
+            _(":") + str(p.readerr()))
+
+def umount(target):
+    p = process("/bin/umount", target)
+    if p.success():
+        return True
+    else:
+        raise MountError(
+            _("Failed to umount {target}").format(
+                target=target) +
+            _(":") + str(p.readerr()))
+
+class BtrfsError(Exception):
+    pass
+
+class Btrfs(object):
+    """
+    Получение информации о btrfs
+    """
+    check_path = "/run/calculate/mount"
+
+    def __init__(self, block):
+        self.block = block
+        if not os.path.exists(block):
+            raise BtrfsError(_("Device not found"))
+
+    @contextmanager
+    def mount(self):
+        dn = None
+        try:
+            makeDirectory(self.check_path)
+            dn = tempfile.mkdtemp(prefix="btrfscheck-", dir=self.check_path)
+            mount(self.block, dn, "btrfs")
+            yield dn
+        except KeyboardInterrupt:
+            raise
+        except MountError as e:
+            if "wrong fs type" in str(e):
+                raise BtrfsError(_("{} is not btrfs").format(self.block))
+            else:
+                raise BtrfsError(str(e))
+        finally:
+            if dn:
+                if os.path.ismount(dn):
+                    umount(dn)
+                os.rmdir(dn)
+            
+    def get_compression(self, rel_dn):
+        rel_dn = rel_dn.lstrip("/")
+        with self.mount() as dn:
+            try:
+                full_dn = os.path.join(dn, rel_dn)
+                if os.path.exists(full_dn):
+                    return xattr.get(full_dn, "btrfs.compression")
+                else:
+                    return ""
+            except IOError as e:
+                if e.errno == errno.ENODATA:
+                    return ""
+                raise BtrfsError(_("Failed to get btrfs compression"))
+
+    @property
+    def compression(self):
+        return self.get_compression("")
+
+    def set_compression(self, rel_dn, value):
+        rel_dn = rel_dn.lstrip("/")
+        with self.mount() as dn:
+            try:
+                full_dn = os.path.join(dn, rel_dn)
+                if not os.path.exists(full_dn):
+                    makeDirectory(full_dn)
+                return xattr.set(full_dn, "btrfs.compression", value)
+            except IOError as e:
+                if e.errno == errno.ENODATA:
+                    return ""
+                raise BtrfsError(_("Failed to set btrfs compression"))
+
+    @compression.setter
+    def compression(self, value):
+        self.set_compression("", value)
